<?php

namespace Chemical\Looking\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Chemical\Looking\Http\Requests\LookingRequest;
use Chemical\Looking\Interfaces\LookingRepositoryInterface;
use Chemical\Looking\Models\Looking;

/**
 * Resource controller class for looking.
 */
class LookingResourceController extends BaseController
{

    /**
     * Initialize looking resource controller.
     *
     * @param type LookingRepositoryInterface $looking
     *
     * @return null
     */
    public function __construct(LookingRepositoryInterface $looking)
    {
        parent::__construct();
        $this->repository = $looking;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Chemical\Looking\Repositories\Criteria\LookingResourceCriteria::class);
    }

    /**
     * Display a list of looking.
     *
     * @return Response
     */
    public function index(LookingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Chemical\Looking\Repositories\Presenter\LookingPresenter::class)
                ->$function();
        }

        $lookings = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('looking::looking.names'))
            ->view('looking::looking.index', true)
            ->data(compact('lookings', 'view'))
            ->output();
    }

    /**
     * Display looking.
     *
     * @param Request $request
     * @param Model   $looking
     *
     * @return Response
     */
    public function show(LookingRequest $request, Looking $looking)
    {

        if ($looking->exists) {
            $view = 'looking::looking.show';
        } else {
            $view = 'looking::looking.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('looking::looking.name'))
            ->data(compact('looking'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new looking.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LookingRequest $request)
    {

        $looking = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('looking::looking.name')) 
            ->view('looking::looking.create', true) 
            ->data(compact('looking'))
            ->output();
    }

    /**
     * Create new looking.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LookingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $looking                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('looking::looking.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('looking/looking/' . $looking->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/looking/looking'))
                ->redirect();
        }

    }

    /**
     * Show looking for editing.
     *
     * @param Request $request
     * @param Model   $looking
     *
     * @return Response
     */
    public function edit(LookingRequest $request, Looking $looking)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('looking::looking.name'))
            ->view('looking::looking.edit', true)
            ->data(compact('looking'))
            ->output();
    }

    /**
     * Update the looking.
     *
     * @param Request $request
     * @param Model   $looking
     *
     * @return Response
     */
    public function update(LookingRequest $request, Looking $looking)
    {
        try {
            $attributes = $request->all();

            $looking->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('looking::looking.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('looking/looking/' . $looking->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('looking/looking/' . $looking->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the looking.
     *
     * @param Model   $looking
     *
     * @return Response
     */
    public function destroy(LookingRequest $request, Looking $looking)
    {
        try {

            $looking->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('looking::looking.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('looking/looking/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('looking/looking/' . $looking->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple looking.
     *
     * @param Model   $looking
     *
     * @return Response
     */
    public function delete(LookingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('looking::looking.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('looking/looking'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/looking/looking'))
                ->redirect();
        }

    }

    /**
     * Restore deleted lookings.
     *
     * @param Model   $looking
     *
     * @return Response
     */
    public function restore(LookingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('looking::looking.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/looking/looking'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/looking/looking/'))
                ->redirect();
        }

    }

}
